.. _tutorials_mc_repo:

************************
firewheel_repo_tutorials
************************

This FIREWHEEL Model Component repository contains several MCs which are used as examples in FIREWHEEL tutorials.

**NOTE:** These reference model components may have slightly different syntax than those referenced in the `FIREWHEEL Tutorials <https://sandialabs.github.io/firewheel/tutorials/index.html>`_ due to various linting/code formatting, but the logic should closely align.
